// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package company

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"gorm.io/gorm"
	"property-company/errors"
	dbmodel "property-company/model"
	pb_v1 "property-company/pb/v1"
	"time"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)



//
func CompanyChangeFreeGarden(ctx context.Context, req *pb_v1.CompanyChangeFreeGardenRequest) (reply *pb_v1.CompanyChangeFreeGardenReply, err error) {
	reply = &pb_v1.CompanyChangeFreeGardenReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	if req.Id < 0 || req.Count == 0{
		return nil, errors.ParamsError
	}

	company := &dbmodel.TCompany{}
	where := map[string]interface{}{
		"id":req.Id,
	}
	err = company.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		return nil, errors.DataBaseError
	}
	if company.ID == 0 {
		return nil, errors.ErrRecordNotFound
	}


	reply.Origin = &pb_v1.CompanyChangeFreeGardenRequest{
		Id:company.ID,
		Count:int32(company.FreeGardenCount),
	}


	now := time.Now()
	p := &dbmodel.TCompany{}

	values := map[string]interface{}{
		"updated_at":now,
		"free_garden_count":req.Count,
	}

	err = p.Update(database.DB(), where, values)
	if err != nil {
		return nil, errors.DataBaseError
	}

	return reply, nil
}
