// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package company

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
	"property-company/consts"
	"property-company/errors"
	dbmodel "property-company/model"
	pb_v1 "property-company/pb/v1"
)



//
func CompanyInfo(ctx context.Context, req *pb_v1.CompanyInfoRequest) (reply *pb_v1.CompanyInfoReply, err error) {

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	if req.Id < 1 {
		return nil, errors.DataBaseError
	}
	p := dbmodel.TCompany{}
	where := map[string]interface{}{
		"id":req.Id,
	}
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		return nil, errors.DataBaseError
	}
	if p.ID == 0 {
		return nil, errors.ErrRecordNotFound
	}

	reply = &pb_v1.CompanyInfoReply{
		Applicant:p.Applicant,
		ApplicantPhone:p.ApplicantPhone,
		CompanyName:p.CompanyName,
		CompanyPhone:p.CompanyPhone,
		ApplicantDuty:p.ApplicantDuty,
		LegalPerson:p.LegalPerson,
		CompanyAddr:p.CompanyAddr,
		SocialCode:p.SocialCode,
		BusinessLicense:p.BusinessLicense,
		ApplicantIdentification:p.ApplicantIdentification,
		CreatedAt:p.CreatedAt.Format(consts.DateTimeLayout),
		ApproveStatus:int32(p.ApproveStatus),
		LicenseType:int32(p.LicenseType),
		FreeGardenCount:int32(p.FreeGardenCount),
		GardenCount:int32(p.GardenCount),
		Username:p.User,
		Password:"******",
		Expire:int32(p.Expire),
		ApprovedAt:"",
		Site:p.Site,
		Logo:p.Logo,
		Desc:p.Desc,
	}

	if p.ApproveStatus > consts.ApproveStatusWait {
		reply.ApprovedAt = p.ApprovedAt.Format(consts.DateTimeLayout)
	}


	return reply, nil
}
