// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package company

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-company/consts"
	"property-company/errors"
	dbmodel "property-company/model"
	pb_v1 "property-company/pb/v1"
)



//
func CompanyList(ctx context.Context, req *pb_v1.CompanyListRequest) (reply *pb_v1.CompanyListReply, err error) {
	reply = &pb_v1.CompanyListReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	if req.PageSize < 1 {
		req.PageSize = 10
	}
	if req.Page < 1 {
		req.Page = 1
	}
	p := dbmodel.TCompany{}
	where := map[string]interface{}{
		"company_name like":"%"+req.CompanyName+"%",
	}
	if req.ApproveStatus > 0 {
		where["approve_status"] = req.ApproveStatus
	}
	if req.CompanyName == "" {
		where = nil
	}
	count, err := p.Count(database.DB(), where, nil)
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.Total = count
	if count == 0 {
		return reply, nil
	}
	list, err := p.List(database.DB(), where, nil, int(req.Page), int(req.PageSize))
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.List = make([]*pb_v1.CompanyItem, len(list))
	for i, v := range list {
		item := &pb_v1.CompanyItem{
			Id:v.ID,
			Applicant:v.Applicant,
			ApplicantPhone:v.ApplicantPhone,
			CompanyName:v.CompanyName,
			CompanyPhone:v.CompanyPhone,
			ApplicantDuty:v.ApplicantDuty,
			LegalPerson:v.LegalPerson,
			CompanyAddr:v.CompanyAddr,
			SocialCode:v.SocialCode,
			BusinessLicense:v.BusinessLicense,
			ApplicantIdentification:v.ApplicantIdentification,
			CreatedAt:v.CreatedAt.Format(consts.DateTimeLayout),
			ApproveStatus:int32(v.ApproveStatus),
			LicenseType:int32(v.LicenseType),
			FreeGardenCount:int32(v.FreeGardenCount),
			GardenCount:int32(v.GardenCount),
			Username:v.User,
			Password:"******",
			Expire:int32(v.Expire),
			ApprovedAt:"",
			Site:v.Site,
			Logo:v.Logo,
			Desc:v.Desc,
		}
		if v.ApproveStatus > consts.ApproveStatusWait {
			item.ApprovedAt = v.ApprovedAt.Format(consts.DateTimeLayout)
		}
		reply.List[i] = item
	}


	return reply, nil
}
