// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package company

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
	"property-company/errors"
	dbmodel "property-company/model"
	pb_v1 "property-company/pb/v1"
)

func checkCompanyWxAccountApplyInfoParam(req *pb_v1.CompanyWxAccountApplyInfoRequest) error {
	if (req.Cid == 0 && !req.Management) || req.Id == 0 {
		return errors.ParamsError
	}

	return nil
}

//
func CompanyWxAccountApplyInfo(ctx context.Context, req *pb_v1.CompanyWxAccountApplyInfoRequest) (reply *pb_v1.CompanyWxAccountApplyInfoReply, err error) {
	reply = &pb_v1.CompanyWxAccountApplyInfoReply{}
	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	err = checkCompanyWxAccountApplyInfoParam(req)
	if err != nil {
		return nil, err
	}

	merchant := dbmodel.TWxMerchantInfo{}
	where := map[string]interface{}{
		"id": req.Id,
	}
	if req.Cid > 0 {
		where["cid"] = req.Cid
	}
	err = merchant.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		return nil, errors.DataBaseError
	}
	if merchant.ID == 0 {
		return nil, errors.ErrRecordNotFound
	}

	reply.Id = merchant.ID
	subjectInfo := pb_v1.CompanyWxSubjectInfo{}
	businessInfo := pb_v1.CompanyWxBusinessInfo{}
	bankInfo := pb_v1.CompanyWxBankAccountInfo{}
	contactInfo := pb_v1.CompanyWxContactInfo{}
	_ = json.Unmarshal([]byte(merchant.SubjectInfo), &subjectInfo)
	_ = json.Unmarshal([]byte(merchant.BusinessInfo), &businessInfo)
	_ = json.Unmarshal([]byte(merchant.BankAccountInfo), &bankInfo)
	_ = json.Unmarshal([]byte(merchant.ContactInfo), &contactInfo)
	reply.ContactInfo = &contactInfo
	reply.BusinessInfo = &businessInfo
	reply.SubjectInfo = &subjectInfo
	reply.BankAccountInfo = &bankInfo
	if reply.SubjectInfo.CertInfo == nil {
		reply.SubjectInfo.CertInfo = &pb_v1.CompanyWxCertificateInfo{}
	}
	if reply.SubjectInfo.IdentityInfo.IdDocInfo == nil {
		reply.SubjectInfo.IdentityInfo.IdDocInfo = &pb_v1.CompanyWxIdDocInfo{}
	}

	return reply, nil
}
