// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package garden

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
	"property-company/consts"
	"property-company/errors"
	dbmodel "property-company/model"
	pb_v1 "property-company/pb/v1"
)

func checkGardenCanAddParam(req *pb_v1.CompanyCanAddGardenRequest) error {
	switch {
	case req.Cid == 0:
		return status.Error(10003, "公司id不能为空")

	}
	return nil
}

//
func CompanyCanAddGarden(ctx context.Context, req *pb_v1.CompanyCanAddGardenRequest) (reply *pb_v1.CompanyCanAddGardenReply, err error) {
	reply = &pb_v1.CompanyCanAddGardenReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 检查参数
	err = checkGardenCanAddParam(req)
	if err != nil {
		return nil, err
	}

	// 检查公司
	company := dbmodel.TCompany{}
	where := map[string]interface{}{
		"id": req.Cid,
	}
	err = company.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		return nil, errors.DataBaseError
	}
	if company.ID == 0 {
		return nil, errors.UserNotExist
	}
	if company.ApproveStatus != consts.ApproveStatusSuccess {
		return nil, errors.UserStatusError
	}

	//if company.FreeGardenCount >= 0 && company.GardenCount >= company.FreeGardenCount {
	//	return reply, nil
	//}
	reply.CanAdd = true

	return reply, nil
}
