// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package garden

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
	"property-company/errors"
	dbmodel "property-company/model"
	pb_v1 "property-company/pb/v1"
)

func checkCompanyGardenDecreaseParam(req *pb_v1.CompanyGardenDecreaseRequest) error {
	switch {
	case req.Cid < 0:
		return status.Error(10003, "物业公司不能为空")


	}
	return nil
}

//
func CompanyGardenDecrease(ctx context.Context, req *pb_v1.CompanyGardenDecreaseRequest) (reply *pb_v1.CompanyGardenDecreaseReply, err error) {
	reply = &pb_v1.CompanyGardenDecreaseReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 检查参数
	err = checkCompanyGardenDecreaseParam(req)
	if err != nil {
		return nil, err
	}

	// 检查公司
	company := dbmodel.TCompany{}
	where := map[string]interface{}{
		"id":req.Cid,
	}





	values := map[string]interface{}{
		"garden_count":gorm.Expr("garden_count - ?", 1),
	}
	err = company.Update(database.DB(), where, values)
	if err != nil {
		return nil, errors.DataBaseError
	}

	return reply, nil

}

