// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package user

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-company/errors"
	dbmodel "property-company/model"

	pb_v1 "property-company/pb/v1"
)

//
func CompanyUserList(ctx context.Context, req *pb_v1.CompanyUserListRequest) (reply *pb_v1.CompanyUserListReply, err error) {

	reply = &pb_v1.CompanyUserListReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.Cid == 0 {
		return nil, errors.ParamsError
	}
	if req.PageSize == 0 {
		req.PageSize = 10
	}
	if req.Page == 0 {
		req.Page = 1
	}
	reply.Page = req.Page

	p := &dbmodel.TUser{}
	where := map[string]interface{}{}
	if req.Cid > 0 {
		where["cid"] = req.Cid
	}

	reply.Total, err = p.Count(database.DB(), where, nil)
	if err != nil {
		return nil, errors.DataBaseError
	}
	if reply.Total == 0 {
		return reply, nil
	}
	list, err := p.List(database.DB(), where, nil, int(req.Page), int(req.PageSize))
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.List = make([]*pb_v1.CompanyUserItem, len(list))

	for i, v := range list {
		item := &pb_v1.CompanyUserItem{

			Phone:     v.Phone,
			UserName:  v.User,
			Email:     v.Email,
			RealName:  v.RealName,
			CreatedAt: v.CreatedAt.Unix(),
			Id:        v.ID,
		}

		reply.List[i] = item
	}

	return reply, nil
}
