// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package user

import (
	"context"
	"encoding/json"
	"fmt"
	"property-company/consts"
	"property-company/errors"
	dbmodel "property-company/model"
	pb_v1 "property-company/pb/v1"

	"gorm.io/gorm"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"git.getensh.com/common/gopkgs/util"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

//
func Login(ctx context.Context, req *pb_v1.LoginRequest) (reply *pb_v1.LoginReply, err error) {

	reply = &pb_v1.LoginReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.Username == "" || req.Password == "" {
		return reply, errors.ParamsError
	}

	p := &dbmodel.TUser{}
	db := database.DB()

	where := map[string]interface{}{
		"user": req.Username,
	}

	//  查找用户是否存在
	err = p.Find(db, where)
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return reply, errors.UserNotExist
		}
		return reply, errors.DataBaseError
	}
	// 检查密码
	passwd, _ := util.GetMd5Pass(req.Password, consts.CRYPTO_KEY)
	if passwd != p.Password {
		return reply, errors.PasswordError
	}
	company := &dbmodel.TCompany{}
	where = map[string]interface{}{
		"id": p.Cid,
	}
	err = company.Find(database.DB(), where)
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return reply, errors.ErrRecordNotFound
		}
		return reply, errors.DataBaseError
	}

	// 检查审批状态
	if company.ApproveStatus != consts.ApproveStatusSuccess {
		return reply, errors.UserStatusError
	}

	reply.Uid = p.ID
	reply.Cid = p.Cid
	reply.User = p.User
	reply.CompanyName = company.CompanyName
	reply.Super = p.Super

	return reply, nil
}
