// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package user

import (
	"context"
	"encoding/json"
	"fmt"
	"gorm.io/gorm"
	"property-company/consts"
	"property-company/errors"
	dbmodel "property-company/model"
	pb_v1 "property-company/pb/v1"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

// 检查手机是否存在
func CheckPhone(ctx context.Context, req *pb_v1.CheckPhoneRequest) (reply *pb_v1.CheckPhoneReply, err error) {

	reply = &pb_v1.CheckPhoneReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.Phone == ""{
		return nil, errors.ParamsError
	}
	p := &dbmodel.TUser{}
	where := map[string]interface{}{
		"phone":req.Phone,
	}
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		return nil, errors.DataBaseError
	}
	if p.ID == 0 {
		return reply, errors.ErrRecordNotFound
	}

	company := &dbmodel.TCompany{}
	where = map[string]interface{}{
		"id":p.Cid,
	}
	err = company.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		return nil, errors.DataBaseError
	}
	if company.ID == 0 {
		return reply, errors.ErrRecordNotFound
	}
	if company.ApproveStatus != consts.ApproveStatusSuccess {
		return nil, errors.UserStatusError
	}


	return reply, nil
}

